Improve this Doc View Source

Specify custom behavior on blur event.

A blur event fires when an element has lost focus.

Note: As the `blur` event is executed synchronously also during DOM manipulations (e.g. removing a focussed input), AngularJS executes the expression using `scope.$evalAsync` if the event is fired during an `$apply` to ensure a consistent state.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-blur
        ng-blur="expression">
      ...
      </ng-blur>

- as attribute:

      <window, input, select, textarea, a
        ng-blur="expression">
      ...
      </window, input, select, textarea, a>

### Arguments

Param | Type | Details
--- | --- | ---
ngBlur | expression | Expression to evaluate upon blur. (Event object is available as `$event`)

## Examples

See ngClick